@@ -5,7 +5,7 @@
  
 package XML::Compile::Translate::Writer;
 use vars '$VERSION';
-$VERSION = '1.12';
+$VERSION = '1.13';
 
 use base 'XML::Compile::Translate';
 
@@ -490,8 +490,8 @@ sub makeElementAbstract
 sub makeComplexElement
 {   my ($self, $path, $tag, $elems, $attrs, $any_attr) = @_;
     my @elems = odd_elements @$elems;
-    my $tags  = join ', ', even_elements @$elems;
     my @attrs = @$attrs;
+    my $tags  = join ', ', even_elements(@$elems), even_elements(@attrs);
     my @anya  = @$any_attr;
     my $iut   = $self->{ignore_unused_tags};
 
